(function($) {
	/**
	 * 是否开启BUG提示
	 *
	 * @type {boolean} true|false
	 */
	$.debug = config.debug || false;

	/**
	 * HTML文件在ROOT目录文件夹名称
	 *
	 * @type {string}
	 */
	//  $.rootFile = 'views';   //2017-12-19 暂时未用到
})(mui);

(function($) {
	/**
	 * 打开WebView
	 *
	 * @param url
	 * @param id
	 * @param options
	 */
	$.openWebView = function(url, id, options) {
		if(typeof url === 'object') {
			options = url;
			url = options.url;
			id = options.id || url;
		} else {
			if(typeof id === 'object') {
				options = id;
				id = options.id || url;
			} else {
				id = id || url;
			}
		}
		if(url === id && typeof $.md5 === "function") id = $.md5(url);
		if($.os.plus) {
			$.plusReady(function() {
				if(url.indexOf($.rootFile) === 0) url = $.outputRootPath(window.location.pathname.split(plus.runtime.appid).pop()) + url;
				$.openWindow(url, id, options);
			});
		} else {
			if(url.indexOf($.rootFile) === 0) url = $.outputRootPath() + url;
			$.openWindow(url, id, options);
		}
	};

	/**
	 * 打开登陆视图
	 *
	 * @param rootpath 相对根目录{../../}
	 */
	$.openLoginView = function(rootpath) {
		mui.openWebView(rootpath + "views/login/login.html", "login", {
			show: {
				autoShow: true,
				aniShow: "slide-in-bottom"
			}
		})
	}

	/**
	 * 判断登陆后，打开WebView
	 *
	 * @param url
	 * @param id
	 * @param options
	 */
	$.openLoginWebView = function(url, id, options) {
		options = options || {};
		var rootpath = options.rootpath || "../../";
		delete options.rootpath;
		if(isMemberLogin() === true) {
			mui.openWebView(url, id, options);
		} else {
			mui.openLoginView(rootpath);
		}
	}

	/**
	 * 关闭WebView
	 *
	 * @param wvs
	 * @param remove
	 *
	 * @returns {boolean}
	 */
	$.closeWebView = function(wvs, remove) {
		if(!$.os.plus) return false;
		remove = (remove !== false) ? true : false;
		$.plusReady(function() {
			wvs = wvs || plus.webview.currentWebview().id;
			if(typeof wvs === "string") wvs = [wvs];
			if(remove === true) {
				for(var i = 0; i < wvs.length; i++) {
					plus.webview.getWebviewById(wvs[i]).close();
				}
			} else {
				var appId = plus.runtime.appid;
				var all = plus.webview.all();
				if(all.length > wvs.length) {
					for(var i = 0; i < all.length; i++) {
						if(jQuery.inArray(all[i].id, wvs) < 0 && all[i].id !== appId) {
							all[i].close();
						}
					}
				}
			}
		});
	};

	/**
	 * 刷新WebVeiw
	 *
	 * @param wvs
	 *
	 * @returns {boolean}
	 */
	$.reloadWebView = function(wvs) {
		if(!$.os.plus) return false;
		$.plusReady(function() {
			wvs = wvs || plus.webview.currentWebview().id;
			if(typeof(wvs) === 'string') wvs = [wvs];
			for(var i in wvs) {
				plus.webview.getWebviewById(wvs[i]).reload(true);
			}
		});
	};

	/**
	 * 输出WebView
	 *
	 * @returns {boolean}
	 */
	$.consoleWebView = function() {
		if(!$.os.plus) return false;
		$.plusReady(function() {
			console.log("-------------------------------------------------------------------------------------------------------------------------------------------------")
			var all = plus.webview.all();
			for(var i in all) {
				console.log(all[i].id);
			}
		});
	};
})(mui);

(function($) {
	/**
	 * JSON转换为HTML
	 *
	 * @param {object} data 数据
	 * @param {function} itemTpl 单条信息模板
	 *
	 * @returns {string} HTML内容
	 */
	$.outputJsonHtml = function(data, itemTpl) {
		var html = '';
		if(jQuery.isArray(data) && data.length > 0) {
			for(var index = 0; index < data.length; index++) html += itemTpl(index, data[index]);
		} else if(jQuery.isPlainObject(data) && !jQuery.isEmptyObject(data)) {
			for(var index in data) html += itemTpl(index, data[index]);
		} else if(typeof(data) === "number" && parseInt(data) > 0) {
			for(var index = 0; index < parseInt(data); index++) html += itemTpl(index, parseInt(data));
		}
		return html;
	};

	/**
	 * 给指定的容器的指定位置输出HTML（JSON转换为HTML）
	 *
	 * @param {string|boolean} container 容器(DOM ID)
	 * @param {object} data 数据
	 * @param {function} itemTpl 单条信息模板
	 * @param {function} warpTpl 信息内容包裹模板
	 * @param {string} outputType 插入HTML方式
	 */
	$.outputContainerHtml = function(container, data, itemTpl, warpTpl, outputType) {
		itemTpl = typeof itemTpl === "function" ? itemTpl : function() {
			return "";
		};
		warpTpl = typeof warpTpl === "function" || warpTpl === null ? warpTpl : function(itemHtml) {
			return itemHtml;
		};
		var outputHtml = "";
		if(warpTpl === null) {
			outputHtml = itemTpl(data);
		} else {
			outputHtml = (jQuery.inArray(outputType, ['in_append', 'in_prepend']) !== -1) ? $.outputJsonHtml(data, itemTpl) : warpTpl($.outputJsonHtml(data, itemTpl));
		}
		if(container !== false) {
			switch(outputType) {
				case "append":
				case "in_append":
					jQuery(container).append(outputHtml);
					break;
				case "prepend":
				case "in_prepend":
					jQuery(container).prepend(outputHtml);
					break;
				case "after":
					jQuery(container).after(outputHtml);
					break;
				case "before":
					jQuery(container).before(outputHtml);
					break;
				default:
					jQuery(container).html(outputHtml);
					break;
			}
		}
		return outputHtml;
	};
})(mui);

(function($) {
	/**
	 * 通用AJAX方法
	 *
	 * @param string url AJAX URL地址
	 * @param object params AJAX 参数
	 * @param object setting AJAX设置
	 * @param number retry 尝试次数
	 */
	$.ajaxService = function(url, params, setting, retry) {
		if($.isFunction($.isEnableNetwork) && $.isEnableNetwork() === false) {
			$.toast("链接超时，请检查网络是否正常。");
		} else {
			params = params || {};
			retry = retry || 3;

			var callSuccess = setting.onSuccess || function(data) {
				return false;
			};
			var callError = setting.onError || function(data) {
				if(data !== "没有相关信息") $.toast(data);
			};
			setting = jQuery.extend({
				"url": url,
				"data": params,
				"type": "post",
				"async": true,
				"dataType": "json",
				"timeout": 10000,
				"success": function(data, status, xhr) {
					if($.isObject(data) && (parseInt(data.code) === 1 || parseInt(data.status) === 1)) {
						if(mui.isPlainObject(data.cartInfo) && !mui.isEmptyObject(data.cartInfo)) {
							jQuery('[data-cart="countBadge"]').html('<span class="mui-badge mui-badge-danger">' + data.cartInfo.count + '</span>');
							mui.cartStorage.setItem(data.cartInfo);
							mui.plusReady(function() {
								var wv = plus.webview.getLaunchWebview();
								wv.evalJS("changeCartNum()");
							});
						}
						var extra = $.extend({}, data);
						callSuccess(data.data, (data.page || null), mui.removeJSON(extra, ['code', 'status', 'msg', 'data', 'page']));
					} else {
						if($.debug) console.log(JSON.stringify({
							"url": url,
							"params": params,
							"error": data.msg,
							"status": code,
							"xhr": xhr
						}));
						callError(data.msg);
					}
				},
				"error": function(xhr, status, error) {
					retry--;
					if(retry > 0) {
						$.ajaxService(url, params, setting, retry);
					} else {
						if($.debug) console.log(JSON.stringify({
							"url": url,
							"params": params,
							"status": status,
							"xhr": xhr,
							"error": error
						}));
						switch(status) {
							case "timeout":
							case "error":
							case "abort":
							case "parsererror":
							default:
								$.toast("链接超时，请检查网络是否正常。");
								break;
						}
					}
				}
			}, (setting || {}));
			if(setting.onSuccess) delete setting.onSuccess;
			if(setting.onError) delete setting.onError;
			jQuery.ajax(setting);
		}
	}
})(mui);

(function($) {
	var storage = {
		itemKey: function(type, code) {
			return jQuery.trim(type) + '-' + jQuery.trim(code);
		},
		setItem: function(key, value, isSession) {
			if(jQuery.isPlainObject(value)) value = JSON.stringify(value);
			(typeof value === "string" && jQuery.trim(value) !== "") ? (isSession ? sessionStorage.setItem(key, value) :
				localStorage.setItem(key, value)) : storage.delItem(key, isSession);
		},
		getItem: function(key, returnJson, isSession) {
			var value = (isSession) ? sessionStorage.getItem(key) : localStorage.getItem(key);
			return returnJson === true ? (mui.isJSON(value) ? JSON.parse(value) : {}) : value;
		},
		delItem: function(key, isSession) {
			isSession ? sessionStorage.removeItem(key) : localStorage.removeItem(key);
		},
		setStorage: function(type, code, value) {
			if(typeof code === "string" && jQuery.trim(code) !== "" && typeof type === "string" && jQuery.trim(type) !== "")
				type === 'session' ? storage.setItem(code, value, true) : storage.setItem(storage.itemKey(type, code), value, false);
		},
		getStorage: function(type, code, returnJson) {
			if(typeof code === "string" && jQuery.trim(code) !== "" && typeof type === "string" && jQuery.trim(type) !== "")
				return type === 'session' ? storage.getItem(code, returnJson, true) : storage.getItem(storage.itemKey(type, code), returnJson, false);
		},
		removeStorage: function(type, code) {
			if(typeof code === "string" && jQuery.trim(code) !== "" && typeof type === "string" && jQuery.trim(type) !== "")
				type === "session" ? storage.delItem(code, true) : storage.delItem(storage.itemKey(type, code), false);
		},
		clearAll: function() {
			localStorage.clear();
			sessionStorage.clear();
		},
		clearStorage: function(type) {
			if(typeof type === "string" && jQuery.trim(type) !== "") {
				if(type === 'session') sessionStorage.clear();
				else if(type === 'all') storage.clearAll();
				else
					for(var key in localStorage)
						if(key.indexOf(type + '-') === 0) localStorage.removeItem(key);
			}
		}
	};
	var cache = {
		type: 'base',
		code: '',
		setItem: function(value) {
			storage.setStorage(this.type, this.code, value);
		},
		getItem: function(returnItem) { //(string,true,false)string时缓存值必须为json格式
			if(typeof returnItem === "string" && jQuery.trim(returnItem) !== "") {
				var item = storage.getStorage(this.type, this.code, true);
				return(typeof(item[returnItem]) !== 'undefined') ? item[returnItem] : null;
			}
			return storage.getStorage(this.type, this.code, returnItem);
		},
		delItem: function() {
			storage.removeStorage(this.type, this.code);
		},
		clear: function() {
			storage.removeStorage("all");
		},
		remove: function() {
			storage.removeStorage(this.type);
		},
		changeItem: function(code, value) {
			var item = storage.getItem(true);
			if(typeof code !== 'undefined' && mui.isPlainObject(code)) {
				item = jQuery.extend({}, item, code);
			} else if(mui.isNoEmptyString(code) && typeof(value) !== 'undefined') {
				item[code] = value;
			}
			this.setItem(item);
		}
	}
	var storageCode = {
		"struct": "S",
		"global": "G",
		"member": "M",
		"interim": "I",
		"session": "session"
	};
	var structStorage = jQuery.extend({}, cache, {
			type: storageCode["struct"]
		}), //结构缓存（重要缓存，一般情况不可以删除）
		globalStorage = jQuery.extend({}, cache, {
			type: storageCode["global"]
		}), //全局缓存
		memberStorage = jQuery.extend({}, cache, {
			type: storageCode["member"]
		}), //会员缓存 记录会员的信息（用户）
		interimStorage = jQuery.extend({}, cache, {
			type: storageCode["interim"]
		}), //临时缓存 页面间值的传递
		sessionStorage = jQuery.extend({}, cache, {
			type: storageCode["session"]
		}); //当前页面缓存
	mui.removeStorge = function(type) {
		if(jQuery.isArray(type)) {
			for(var i = 0; i < type.length; i++)
				if(typeof storageCode[type[i]] === "string") storage.clearStorage(storageCode[type[i]]);
		} else {
			if(typeof storageCode[type] === "string") storage.clearStorage(storageCode[type]);
		}
	};
	mui.memberStorage = jQuery.extend({}, memberStorage, {
		code: "member"
	});
	mui.tokenStorage = jQuery.extend({}, memberStorage, {
		code: "token"
	});
})(mui);