(function($) {
	/**
	 * 获取当前年第一天跟最后一天
	 * return 
	 */
	$.getFirstAndLastDay = function() {
		var arr = [];
		var date = new Date;
		var year = date.getFullYear();
		arr[0] = year + "-01-01";
		arr[1] = year + "-12-31";
		return arr;
	}
	/**
	 * 处理银行卡字符串,4位分割
	 */
	$.dealBankNum = function(money) {
		var intSum = money.replace(/\B(?=(?:\d{4})+$)/g, ' ');
		return intSum;
	}
	/**
	 * 处理金额字符串,千位分割
	 */
	$.dealMoney = function(money) {
		var intSum = money.replace(/\B(?=(?:\d{3})+$)/g, ',');
		return intSum;
	}
	$.dealStr = function(num, str, delimiter) {
		var regk = new RegExp("/\B(?=(?:\d{" + num + "})+$)/g");
		var strNew = regk.test(str)
		console.log(strNew);
		var intSum = str.replace(strNew, delimiter);
		//		var intSum = str.replace(/\B(?=(?:\d{2})+$)/g, delimiter);
		return intSum;
	}
	/**
	 * 身份证中间替换为星号
	 *
	 * @param card 身份证号码
	 * @param hide 是否隐藏中间十二位身份证号码
	 *
	 * @returns {string}
	 */
	$.outputCard = function(card, hide) {
		if(!(/(^\d{18}$)|(^\d{17}(\d|X|x)$)/).test(card)) return ""
		hide = hide || true;
		return hide === true ? card.replace(/(\d{4})\d{12}(\w{2})/, '$1************$2') : "";
	};
	/**
	 * 身份证取后六位中间两位替换为星号
	 *
	 * @param card 身份证号码
	 *
	 * @returns {string}
	 */
	$.outputSixCard = function(card) {
		if(!(/(^\d{18}$)|(^\d{17}(\d|X|x)$)/).test(card)) return ""
		card = card.substring(12)
		return card.replace(/(\d{2})\d{2}(\w{2})/, '$1**$2');
	};
	/**
	 * 根据身份证号取相关信息
	 *
	 * @param card 身份证号码
	 * @param state 1 性别
	 * 				2 出生日期
	 *
	 * @returns {string}
	 */
	$.outputMsg = function(card, state) {
		if(!(/(^\d{18}$)|(^\d{17}(\d|X|x)$)/).test(card)) return ""
		switch(state) {
			case 1:
				if(parseInt(card.substr(16, 1)) % 2 == 1) {
					return "男";
				} else {
					return "女";
				}
				break;
			case 2:
				var birth = card.substring(6, 10) + "-" + card.substring(10, 12) + "-" + card.substring(12, 14);
				return birth;
				break;
			default:
				return "";
				break;
		}
	};
	/**
	 * 获得beginYear年到今年年份集合,用于单选的数据源
	 */
	$.getYearJsonArr = function(beginYear) {
		var myDate = new Date();
		var year = myDate.getFullYear();
		var time = [];
		for(var i = beginYear; i <= year; i++) {
			var param = {};
			param.text = i;
			time.push(param);
		}
		return time;
	}
	/**
	 * 获取当前以后num天的json串 
	 * 单个格式{"text":"2018-08-23(周四)"}
	 * 不包含周六周日
	 * @param {Object} num 天数
	 */
	$.getTimeData = function(num) {
		function getDataString(date) {
			var y = 1900 + date.getYear();
			var m = (date.getMonth() + 1) > 9 ? (date.getMonth() + 1) : "0" + (date.getMonth() + 1);
			var d = date.getDate() > 9 ? date.getDate() : "0" + date.getDate();
			var a = new Array("日", "一", "二", "三", "四", "五", "六");
			var week = date.getDay();
			var weekstr = "周" + a[week];
			if(week != 0 && week != 6) {
				return y + "-" + m + "-" + d + "(" + weekstr + ")";
			}
			return "";
		}

		function getTimeString(num) {
			var curDate = new Date();
			return new Date(curDate.getTime() + num * 24 * 60 * 60 * 1000)
		}
		var time = [];
		var count = 0;
		for(var i = 0; i < 100; i++) {
			var data = getTimeString(i);
			var t = getDataString(data);
			if(t != "") {
				var data = {};
				data["text"] = t;
				time.push(data);
				count++;
			}
			if(count == 5) {
				return JSON.stringify(time);
			}
		}
		return "";
	}
})(mui);

(function($) {
	/**
	 * 计算两点之间距离
	 * 例mui.getDistance(41.124932,121.140151,41.114944,121.134669)
	 */
	$.getDistance = function(lat1, lng1, lat2, lng2) {
		var radLat1 = lat1 * Math.PI / 180.0;
		var radLat2 = lat2 * Math.PI / 180.0;
		var a = radLat1 - radLat2;
		var b = lng1 * Math.PI / 180.0 - lng2 * Math.PI / 180.0;
		var s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) +
			Math.cos(radLat1) * Math.cos(radLat2) * Math.pow(Math.sin(b / 2), 2)));
		s = s * 6378.137; // EARTH_RADIUS;
		s = Math.round(s * 10000) / 10000;
		return s;
	}
})(mui);

(function($) {
	function add0(m) {
		return m < 10 ? '0' + m : m
	}
	/**
	 * 
	 * @param {Object} data 时间戳
	 * @param {Object} type 1、年-月-日
	 * 						2、年-月-日 时:分:秒
	 */
	$.format = function(data, type) {
		var time = new Date(data);
		var y = time.getFullYear();
		var m = time.getMonth() + 1;
		var d = time.getDate();
		var h = time.getHours();
		var mm = time.getMinutes();
		var s = time.getSeconds();
		switch(type) {
			case "1":
				return y + '-' + add0(m) + '-' + add0(d);
				break;
			case "2":
				return y + '-' + add0(m) + '-' + add0(d) + ' ' + add0(h) + ':' + add0(mm) + ':' + add0(s);
				break;
			default:
				break;
		}

	}
	/**
	 * 生成随机数
	 * @param {Object} index 随机数位数
	 */
	$.randomNum = function(index) {
		var num = "";
		if(index <= 0) {
			return num;
		} else {
			for(var i = 0; i < index; i++) {
				num += Math.floor(Math.random() * 10);;
			}
			return num;
		}

	}
	/**
	 * 判断是否为空(支持变量未定义或者字符串是否为空),为空toast显示msg信息
	 * @param {Object} content 判断的对象
	 * @param {Object} msg 错误提示信息
	 */
	$.isEmptyObj = function(content, msg) {
		if(typeof(content) == "string") {
			//去掉所有空格
			content = content.replace(/\s+/g, "");
		}
		if(content == null || content == "" || content == undefined) {
			mui.toast(msg);
			return false;
		}
		return true;
	}

	/**
	 * 判断身份证号是否正确
	 * @param {Object} card
	 */
	$.isCard = function(card) {
		if(!(/(^\d{18}$)|(^\d{17}(\d|X|x)$)/).test(card)) {
			return true;
		} else {
			return false;
		}
	}
	/**
	 * 判断电话号码是否正确
	 * @param {Object} content 电话号码
	 * @param {Object} msg 错误提示信息
	 */
	$.isMobile = function(content, msg) {
		if(/^(13[0-9]|14[579]|15[0-3,5-9]|16[6]|17[0135678]|18[0-9]|19[89])[0-9]{8}$/.test(content)) {
			return true;
		} else {
			mui.toast(msg);
			return false;
		}
	}
	/**
	 * 判断电话号码是否正确
	 * @param {Object} content 电话号码
	 * @param {Object} msg 错误提示信息
	 */
	$.isMobileNew = function(content, msg) {
		if(/^(1)[0-9]{10}$/.test(content)) {
			return true;
		} else {
			mui.toast(msg);
			return false;
		}
	}
	/**
	 * 计时器
	 * @param {Object} content 上下文对象
	 * @param {Object} time 计时事件
	 * @param {Object} colorDisable 不可点击时的颜色(可选)
	 * @param {Object} colorNormal 可点击时的颜色(可选)
	 * @param {Object} unit 单位(可选)
	 */
	$.intervalStart = function(content, time, colorDisable, colorNormal, unit) {
		var colorDisable = colorDisable || "#cacaca";
		var colorNormal = colorNormal || "#007AFF";
		var unit = unit || "秒";
		var interval; //计时器
		interval = window.setInterval(function() {
			time -= 1;
			if(time == 0) {
				clearInterval(interval);
				content.innerHTML = "获取验证码";
				content.disabled = false;
				content.style.color = "#FFF";
				content.style.borderColor = colorNormal;
			} else {
				content.innerHTML = time + unit;
				content.disabled = true;
				content.style.color = colorDisable;
				content.style.borderColor = colorDisable;
			}
		}, 1000, 0);
	}
	/**
	 * 删除数组中的指定值
	 * @param {Object} val
	 */
	$.removeByValue = function(val) {
		for(var i = 0; i < this.length; i++) {
			if(this[i] == val) {
				this.splice(i, 1);
				break;
			}
		}
	}
	/**
	 * 查找url中指定参数的值
	 *
	 * @param code
	 *
	 * @returns {string}
	 */
	$.getRequest = function(code) {
		var name = window.location.search.substr(1).match(new RegExp("(^|&)" + code + "=([^&]*)(&|$)"));
		return(name !== null) ? decodeURI(name[2]) : "";
	};
	/**
	 * 关闭WebView
	 *
	 * @param wvs
	 * @param remove
	 *
	 * @returns {boolean}
	 */
	$.closeWebView = function(wvs, remove) {
		if(!$.os.plus) return false;
		remove = (remove !== false) ? true : false;
		$.plusReady(function() {
			wvs = wvs || plus.webview.currentWebview().id;
			if(typeof wvs === "string") wvs = [wvs];
			if(remove === true) {
				for(var i = 0; i < wvs.length; i++) {
					plus.webview.getWebviewById(wvs[i]).close();
				}
			} else {
				wvs.push(plus.runtime.appid);
				var all = plus.webview.all();
				for(var i = 0; i < all.length; i++) {
					if(jQuery.inArray(all[i].id, wvs) < 0) {
						all[i].close();
					}
				}
			}
		});
	};
	/**
	 * 校验token
	 * @param Object login token失效后是否登录
	 */
	$.checkLogin = function(login, from) {
		var effectiveTime = Number(jztGetTokenEffectiveTime());
		var loginTime = Number(jztGetTokenTime());
		var currentTime = Number((new Date()).valueOf());
		var loginingTime = (currentTime - loginTime) / 1000
		if(loginingTime < effectiveTime) {
			//在有效期内
			config.userIsEffective = true;
			return true;
		} else {
			config.userIsEffective = false;
			if(jztGetFreToken()) {
				jztFreshToken({
					"success": function() {
						window.location.reload()
					},
					"error": function() {

					}
				})
			} else {
				if(!login) {
					//处理没登录也不需要处理的页
				} else {
					if(from) {
						mui.openWindow("view/my/login/login-all.html?from=home")
					} else {
						mui.openWindow("../../view/my/login/login-all.html")
					}
				}
			}
			return false;
		}
	}
	/*
	 * 通用Axios方法
	 * @param string url Axios URL地址
	 * @param object params Axios 参数
	 * @param object setting Axios设置
	 * @param object type Axios请求("get\post") 默认get
	 * @param object login 是否为登陆接口
	 * @param object needLogin 是否需要登录
	 */
	$.axiosService = function(url, params, setting, type, login, needLogin) {
		var isLogin = login || false;
		var isNeedLogin = needLogin == undefined ? true : needLogin
		if($.isFunction($.isEnableNetwork) && $.isEnableNetwork() === false) {
			$.toast("链接超时，请检查网络是否正常。");
		} else {
			params = params || {};
			axios.interceptors.request.use(function(config) {
				//拦截器中添加请求参数
//				config.params.verson='1.0.0'
				if(isLogin) {
					config.headers.Authorization = "Basic YXBwOmFwcA==";
				} else {
					if(isNeedLogin) {
//												config.headers.Authorization = "Bearer " + "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJsaWNlbnNlIjoid2lzaCIsImNvZGUiOjAsInVzZXJfbmFtZSI6IjMwMiIsInNjb3BlIjpbInNlcnZlciJdLCJleHAiOjE2MjEwNjY2MTMsInVzZXJJZCI6MzAyLCJhdXRob3JpdGllcyI6WyJST0xFX1VTRVIiXSwianRpIjoiX1BIZ1QtS19VaWs1aDMtRC1IWmdfT3NuYnlzIiwiY2xpZW50X2lkIjoiYXBwIn0.XAGQCaxWmSmqHC5Wz1GyLFhwWXyrVtGIJI6sJmQ3qg0";
						if(jztGetToken() != null) {
//							在header中添加token
							var token = jztGetToken();
							config.headers.Authorization = "Bearer " + token;
						}
					}
				}
				return config;
			}, function(error) {
				return Promise.reject(error);
			});
			// 拦截响应response,并做一些错误处理
			axios.interceptors.response.use(function(response) {

				// 对响应数据做处理
				return response;
			}, function(error) {
				if(error.response == undefined) {

					mui.toast("网络异常，请稍后再试！");
					return;

					//					mui.openWindow("../../view/my/login/login-all.html")
				}

				switch(error.response.status) {
					case 401:
						if(config.userIsEffective && !isLogin) {
							app.createNewView(true, "1", "view/my/login/login-all.html")

						}
						if(error.response.data.error == "unauthorized") {
							//登录时账号密码输入错误
							mui.toast("账号或密码错误")
						}
						break;
					case 400:
						if(error.response.data.error == "invalid_grant" && !isLogin) {
							app.createNewView(true, "1", "view/my/login/login-all.html")
						} else {
							//在登录页不作处理
							//							mui.toast(error.response.data.error_description)
						}
						if(isLogin) {
							mui.toast("登录失败")
						}
						//
						break;
					case 500:
						// 对响应错误做处理
						setting.error(error);
						console.log(error)
						console.log(JSON.stringify({
							"url": url,
							"params": params
						}))
						console.log("1")
						$.toast("链接超时,请检查网络是否正常！");
						break;
					default:
						//						mui.openWindow("../../view/my/login/login-all.html")
						mui.toast(error.response.status)
						//						mui.toast("未知异常！");
						break;
				}

				return Promise.reject(error);
			});
			switch(type) {
				case "post":
					axios.post(url, params, {
							timeout: 10000
						})
						.then(function(response) {
							setting.success(response.data);
						})
						.catch(function(error) {
							console.log("url:" + url)
							console.log(error);
						});
					break;
				case "get":
				default:
					axios.get(url, {
							params
						}, {
							timeout: 3000
						})
						.then(function(response) {
							setting.success(response.data);
						})
						.catch(function(error) {
							console.log(error)
						});
			}
		}
	}




	/*
	 * 通用Axios方法-静默不提示
	 * @param string url Axios URL地址
	 * @param object params Axios 参数
	 * @param object setting Axios设置
	 * @param object type Axios请求("get\post") 默认get
	 * @param object login 是否为登陆接口
	 * @param object needLogin 是否需要登录
	 */
	$.axiosServiceL = function(url, params, setting, type, login, needLogin) {
		var isLogin = login || false;
		var isNeedLogin = needLogin == undefined ? true : needLogin
		if($.isFunction($.isEnableNetwork) && $.isEnableNetwork() === false) {
			$.toast("链接超时，请检查网络是否正常。");
		} else {
			params = params || {};
			axios.interceptors.request.use(function(config) {
				//拦截器中添加请求参数
				if(isLogin) {
					config.headers.Authorization = "Basic YXBwOmFwcA==";
				} else {
					if(isNeedLogin) {
//												config.headers.Authorization = "Bearer " + "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJsaWNlbnNlIjoid2lzaCIsInVzZXJfbmFtZSI6IjMwMiIsInNjb3BlIjpbInNlcnZlciJdLCJleHAiOjE1OTQ3NzM2NjMsInVzZXJJZCI6MzAyLCJhdXRob3JpdGllcyI6WyJST0xFX1VTRVIiXSwianRpIjoiMTRjMjE2YWUtMDI3NS00YjU2LWJjNTEtYzhkY2QxNzJmOWRjIiwiY2xpZW50X2lkIjoiYXBwIn0.LjydOERUGbXyxxzaX1b1QpMkEDOS1UHd8VVzQjnR_Q4";
						if(jztGetToken() != null) {
//							在header中添加token
							var token = jztGetToken();
							config.headers.Authorization = "Bearer " + token;
						}
					}
				}
				return config;
			}, function(error) {
				return Promise.reject(error);
			});
			// 拦截响应response,并做一些错误处理
			axios.interceptors.response.use(function(response) {

				// 对响应数据做处理
				return response;
			}, function(error) {
				if(error.response == undefined) {
					return;
				}
				return Promise.reject(error);
			});
			switch(type) {
				case "post":
					axios.post(url, params, {
							timeout: 10000
						})
						.then(function(response) {
							setting.success(response.data);
						})
						.catch(function(error) {
							console.log("url:" + url)
							console.log(error);
						});
					break;
				case "get":
				default:
					axios.get(url, {
							params
						}, {
							timeout: 3000
						})
						.then(function(response) {
							setting.success(response.data);
						})
						.catch(function(error) {
							console.log(error)
						});
			}
		}
	}
})(mui);

(function($) {

	/**
	 * 判断是否联网
	 */
	$.isEnableNetwork = function(t) {
		var network = true;
		if($.os.plus && t === true) {
			if(plus.networkinfo.getCurrentType() == plus.networkinfo.CONNECTION_NONE) {
				network = false;
			}
		}
		return network;
	}
	/**
	 * 获取网络类型 plusReady后使用
	 */
	$.getNetwork = function() {
		var networkTypes = {};
		networkTypes[plus.networkinfo.CONNECTION_UNKNOW] = "未知";
		networkTypes[plus.networkinfo.CONNECTION_NONE] = "未连接网络";
		networkTypes[plus.networkinfo.CONNECTION_ETHERNET] = "有线网络";
		networkTypes[plus.networkinfo.CONNECTION_WIFI] = "WiFi网络";
		networkTypes[plus.networkinfo.CONNECTION_CELL2G] = "2G蜂窝网络";
		networkTypes[plus.networkinfo.CONNECTION_CELL3G] = "3G蜂窝网络";
		networkTypes[plus.networkinfo.CONNECTION_CELL4G] = "4G蜂窝网络";
		return networkTypes[plus.networkinfo.getCurrentType()];
	}
})(mui);

(function($) {
	/**
	 * 显示验证码图形
	 * @param {Object} id 容器id
	 * @param {Object} height 高度(不带单位)
	 * @param {Object} width 宽度(不带单位)
	 */
	$.getGVerify = function(id, height, width) {
		function GVerify(options) { //创建一个图形验证码对象，接收options对象为参数
			this.options = { //默认options参数值
				id: "", //容器Id
				canvasId: "verifyCanvas", //canvas的ID
				width: width, //默认canvas宽度
				height: height, //默认canvas高度
				type: "blend", //图形验证码默认类型blend:数字字母混合类型、number:纯数字、letter:纯字母
				code: ""
			}

			if(Object.prototype.toString.call(options) == "[object Object]") { //判断传入参数类型
				for(var i in options) { //根据传入的参数，修改默认参数值
					this.options[i] = options[i];
				}
			} else {
				this.options.id = options;
			}

			this.options.numArr = "0,1,2,3,4,5,6,7,8,9".split(",");
			this.options.letterArr = getAllLetter();

			this._init();
			this.refresh();
		}

		GVerify.prototype = {
			/**初始化方法**/
			_init: function() {
				var con = document.getElementById(this.options.id);
				var canvas = document.createElement("canvas");
				canvas.id = this.options.canvasId;
				canvas.width = this.options.width;
				canvas.height = this.options.height;
				canvas.style.cursor = "pointer";
				con.appendChild(canvas);
				var parent = this;
				canvas.onclick = function() {
					parent.refresh();
				}
			},
			/**生成验证码**/
			refresh: function() {
				this.options.code = '';
				var canvas = document.getElementById(this.options.canvasId);
				if(canvas.getContext) {
					var ctx = canvas.getContext('2d');
				}
				ctx.textBaseline = "middle";

				ctx.fillStyle = randomColor(180, 240);
				ctx.fillRect(0, 0, this.options.width, this.options.height);

				if(this.options.type == "blend") { //判断验证码类型
					var txtArr = this.options.numArr.concat(this.options.letterArr);
				} else if(this.options.type == "number") {
					var txtArr = this.options.numArr;
				} else {
					var txtArr = this.options.letterArr;
				}
				for(var i = 1; i <= 4; i++) {
					var txt = txtArr[randomNum(0, txtArr.length)];
					this.options.code += txt;
					ctx.font = '20px SimHei';
					ctx.fillStyle = randomColor(50, 160); //随机生成字体颜色
					ctx.shadowBlur = randomNum(-3, 3);
					ctx.shadowColor = "rgba(0, 0, 0, 0.3)";
					var x = this.options.width / 5 * i;
					var y = this.options.height / 2;
					var deg = randomNum(-30, 30);
					/**设置旋转角度和坐标原点**/
					ctx.translate(x, y);
					ctx.rotate(deg * Math.PI / 180);
					ctx.fillText(txt, 0, 0);
					/**恢复旋转角度和坐标原点**/
					ctx.rotate(-deg * Math.PI / 180);
					ctx.translate(-x, -y);
				}
				/**绘制干扰线**/
				for(var i = 0; i < 4; i++) {
					ctx.strokeStyle = randomColor(40, 180);
					ctx.beginPath();
					ctx.moveTo(randomNum(0, this.options.width / 2), randomNum(0, this.options.height / 2));
					ctx.lineTo(randomNum(0, this.options.width / 2), randomNum(0, this.options.height));
					ctx.stroke();
				}
				/**绘制干扰点**/
				for(var i = 0; i < this.options.width / 4; i++) {
					ctx.fillStyle = randomColor(0, 255);
					ctx.beginPath();
					ctx.arc(randomNum(0, this.options.width), randomNum(0, this.options.height), 1, 0, 2 * Math.PI);
					ctx.fill();
				}
			},
			/**验证验证码**/
			validate: function(code) {
				var verifyCode = code.toLowerCase();
				var v_code = this.options.code.toLowerCase();
				if(verifyCode == v_code) {
					return true;
				} else {
					return false;
				}
			}
		}

		/**生成字母数组**/
		function getAllLetter() {
			var letterStr = "a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z";
			return letterStr.split(",");
		}
		/**生成一个随机数**/
		function randomNum(min, max) {
			return Math.floor(Math.random() * (max - min) + min);
		}
		/**生成一个随机色**/
		function randomColor(min, max) {
			var r = randomNum(min, max);
			var g = randomNum(min, max);
			var b = randomNum(min, max);
			return "rgb(" + r + "," + g + "," + b + ")";
		}
		return new GVerify(id);
	}
})(mui);

(function($) {
	/**
	 * 获取定位经纬度
	 */
	$.getLocation = function(settings) {
		mui.plusReady(function() {
			// 使用高德地图地位模块获取位置信息
			plus.geolocation.getCurrentPosition(function(p) {
				//经度 p.coords.longitude
				//纬度 p.coords.latitude
				settings.success(p);
			}, function(e) {
				settings.error();
				//				mui.toast('定位失败,请稍后重试');
			}, {
				provider: 'amap',
				enableHighAccuracy: false
			});
		})
	}
})(mui);

(function($) {
	/**
	 * 设置回传值(使用mui.back())
	 * @param {Object} key
	 * @param {Object} json
	 */
	$.setBackJSON = function(key, json) {
		mui.plusReady(function() {
			mui.init({
				beforeback: function() {
					var opener = plus.webview.currentWebview().opener();
					mui.fire(opener, key, json);
					return true;
				}
			});
		})
	}
	/**
	 * 获取回传值
	 * @param {Object} key
	 * @param {Object} settings
	 */
	$.getBackJSON = function(key, settings) {
		mui.plusReady(function() {
			window.addEventListener(key, function(e) {
				settings.success(e.detail);
			});
		})
	}
})(mui);